# PyHnefatafl - A Python library for the Hnefatafl board game

Allowing you to play the game of Hnefatafl in Python. Based on `chess`: https://pypi.org/project/chess/

## Progress

- [x] Basic game logic of 11x11 Hnefatafl
- [x] Tests for the game's rules
  - [ ] Expand tests to cover more rules / variants
- [x] A couple of variant games
- [ ] Better configuration of variant games (Brandubh, Tablut, Ard Rí, etc.)
  - [ ] Define variant games in a config file or class
  - [ ] Split game rules from board rules (e.g. 11x11, 9x9, 7x7)